/****************************************************************
 *								*
 * Copyright (c) 2001-2024 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef RESOLVE_LAB_INCLUDED
#define RESOLVE_LAB_INCLUDED

void resolve_lab(mtreenode *node, void *arg);

#endif /* RESOLVE_LAB_INCLUDED */
